@@ -30,6 +30,8 @@ FROM_EMAIL = getattr(django_settings, "MAGICAUTH_FROM_EMAIL")
 # Login view :
 # the view in which your user enters their email to start the login process.
 LOGIN_URL = getattr(django_settings, "MAGICAUTH_LOGIN_URL", "login/")
+# Template for the login view if you want to customise it. It has to contain a form, with a field
+# with type="email" and name="email".
 LOGIN_VIEW_TEMPLATE = getattr(
     django_settings, "MAGICAUTH_LOGIN_VIEW_TEMPLATE", "magicauth/login.html"
 )
@@ -96,3 +98,14 @@ EMAIL_UNKNOWN_MESSAGE = getattr(
 WAIT_SECONDS = getattr(
     django_settings, "MAGICAUTH_WAIT_SECONDS", 3
 )
+# This enables the 2FA OTP field
+ENABLE_2FA = getattr(
+    django_settings, "MAGICAUTH_ENABLE_2FA", False
+)
+# Can be 6 or 8 (https://django-otp-official.readthedocs.io/en/stable/overview.html#django_otp.plugins.otp_totp.models.TOTPDevice.digits)
+OTP_NUM_DIGITS = getattr(
+    django_settings, "MAGICAUTH_OTP_NUM_DIGITS", 6
+)
+if OTP_NUM_DIGITS not in [6, 8] :
+    raise ValueError("OTP_NUM_DIGITS must be either 6 or 8 character long --> https://django-otp-official.readthedocs.io/en/stable/overview.html#django_otp.plugins.otp_totp.models.TOTPDevice.digits")
+
