@@ -4,6 +4,6 @@ from django.views.generic import TemplateView
 urlpatterns = [
     path("", include("magicauth.urls")),
     path(
-        "test_home/", TemplateView.as_view(template_name="home.html"), name="test_home"
+        "landing/", TemplateView.as_view(template_name="home.html"), name="test_home"
     ),
 ]
